#!/bin/bash
# Prevent from Ctrl + C
# Includes scripts
#Setting folder
PROJECT_FOLDER="IntoVPN"
INSTALL_FOLDER="/usr/local/"
temp_folder="/usr/local/IntoVPNLinuxTemp"
extract_folder=$INSTALL_FOLDER$PROJECT_FOLDER
files_data="Datas.zip Executable.zip IntoVPNCmdLinux.zip Lib.zip"
working_folder=$PWD
link_update="https://download.intovpn.net/cmdlines/install/linux/1.0.0.0"
glb_title="Welcome to IntoVPN.net"
sub_title="Installation"
msg_checking="Checking system ..."
msg_not_sp_tun="The application is exiting because TUN is not supported by system. Try again the next time!"
msg_tun_ready="TUN driver is ready. Continue ..."
msg_tun_error="The application is exiting because TUN driver can not be actived. Try again the next time!"
msg_sys_error="The application is exiting because has error on the system. Try again the next time!"
msg_ready_update="Checking system is done. Start updating the application!"
msg_dload_error="The application is exiting because has error while updating. Try again the next time!"
msg_extr_error="The application is exiting because has error while extracting files. Try again the next time!"
msg_not_found="The application is exiting because not found config file. Try again the next time!"
msg_done_upddata="Finish updating the application. Please enter any key to start IntoVPN.net:"
clear
trap '' 2
echo "=========" $glb_title "========="
echo $sub_title
echo "==============================="
# Check support TUN/TAP on the system
echo $msg_checking
sudo cat /dev/net/tun 2>&1 >/dev/null
if [ $? -eq 0 ]; then
	#Not support
	echo $msg_not_sp_tun
	exit 2
fi
#Support -> continue
#Check TUN is actived?
sudo lsmod | grep tun  2>&1 >/dev/null
if [ $? -eq 1 ]; then
	#Not actived -> active now!
	sudo modprobe tun
fi
#Create TAP/TUN
sudo ip tuntap add dev tap-intovpn mod tap 2>&1 >/dev/null
sudo ip tuntap add dev tun-intovpn mod tun 2>&1 >/dev/null
#TUN/TAP drivers is ready!
echo $msg_tun_ready
#Enable forwarding
echo 1 > /proc/sys/net/ipv4/ip_forward 2>&1 >/dev/null
if [ $? -eq 1 ]; then
	#Can't enable forwarding
	echo $msg_sys_error
	exit 2
fi
#Check exists wget
sudo wget --version 2>&1 >/dev/null
if [ $? -eq 1 ]; then
	#Wget has been not installed -> install now!
	sudo yum install wget
	if [ $? -eq 1 ]; then
		#Installation is failed
		echo $msg_sys_error
		exit 2
	fi
fi
#Check exists autoconf
sudo autoconf --version 2>&1 >/dev/null
if [ $? -eq 1 ]; then
	#Autoconf has been not installed -> install now!
	sudo yum install autoconf
	if [ $? -eq 1 ]; then
		#Installation is failed
		echo $msg_sys_error
		exit 2
	fi
fi
#Check exists gcc
sudo gcc --version 2>&1 >/dev/null
if [ $? -eq 1 ]; then
	#Gcc has been not installed -> install now!
	sudo yum install gcc
	if [ $? -eq 1 ]; then
		#Installation is failed
		echo $msg_sys_error
		exit 2
	fi
fi
#Ready
echo $msg_ready_update
#Download datas
#Delete before if exists
if [ -d "$temp_folder/" ]; then
	#Delete
	rm -rf $temp_folder
fi
is_failed=0
IFS=' ' read -r -a array_files <<< "$files_data"
for element in "${array_files[@]}"
do
	url=$link_update/$element
    echo "Downloading from $url ..."
	wget --no-check-certificate -P $temp_folder $url
	if [ $? -eq 1 ]; then
		echo "Has Error: while downloading from $url"
		is_failed=1
		break
	fi
done
if [ $is_failed -eq 1 ]; then
	#Has error while download
	echo $msg_dload_error
	exit 2
fi
#Unzip:
#Delete before if exists
if [ -d "$extract_folder/" ]; then
	#Delete
	rm -rf $extract_folder
fi
is_failed=0
for z_file in "${array_files[@]}"
do
    echo "Extracting file $z_file ..."
	unzip -o $temp_folder/$z_file -d $extract_folder"/"
	if [ $? -eq 1 ]; then
		echo "Has Error: while Extracting file $z_file"
		is_failed=1
		break
	fi
done
if [ $is_failed -eq 1 ]; then
	#Has error while extract
	echo $msg_extr_error
	exit 2
fi
#Delete temp_folder files after
rm -rf $temp_folder
#Install wg
#Check exists wg
sudo wg --version 2>&1 >/dev/null
if [ $? -eq 1 ]; then
	#Wg has been not installed -> install now!
	sudo yum update
	sudo yum install kernel-headers
	sudo yum install elrepo-release epel-release -y
	sudo yum install yum-plugin-elrepo
	sudo yum install kmod-wireguard wireguard-tools -y
	sudo setenforce 0
	sudo mkdir -p /etc/wireguard/
	sudo chmod go+rx /etc/wireguard/
	sudo modprobe wireguard
	if [ $? -eq 1 ]; then
		#Installation is failed
		echo $msg_sys_error
		exit 2
	fi
fi
#Change permissons for all subfolders/files
sudo chmod -R 775 $extract_folder
#Install intovpnclt service
cd $extract_folder/Executable
yum install curl-devel expat-devel gettext-devel openssl-devel zlib-devel
autoreconf -i -v -f
sudo yum install lzo-devel
yum install lz4
sudo yum install pam-devel
sudo chmod -R 755 configure
sudo yum install gettext-devel
sudo yum install automake
sudo yum install libtool
./configure
make
make install
#Set ENV
if [[ $PATH == *"$extract_folder"* ]]; then
	#Exists
	echo "The path exists!"
else
	# If there is no environment variable -> Add to
	echo "Add path ..."  
	echo export PATH="$extract_folder:$PATH" >> ~/.bashrc
	source ~/.bashrc
fi
# Export 
#Complete
echo $msg_done_upddata
read answer
IntoVPNCmdLinux
